@@ -41,8 +41,8 @@ sub get {
 			undef,
 			'item goto-last-edit',
 			undef,
-			'item marker-goto-prev',
-			'item marker-goto-next',
+			'item marker-goto-prev-all',
+			'item marker-goto-next-all',
 			undef,
 			'item goto-line',
 			'item view-dialog-find',
